@@ -31,6 +31,10 @@ def rm_folder(folder_name, empty=False):
   if empty == False:
     rmtree(folder_name,ignore_errors=True)
   else:
+    rmtree(folder_name,ignore_errors=True)
+    mk_folder(folder_name=folder_name)
+    
+  """    
     if is_folder(folder_name) == False :
       return
     
@@ -46,7 +50,8 @@ def rm_folder(folder_name, empty=False):
         if d_empty == True:
           rmtree(d,ignore_errors=True)
 
-
+  """
+  
 delete_folder = rm_folder
 
 ####################################################################################################
@@ -185,7 +190,7 @@ def rm_file(file_name = None, folder = None, regex_pattern=None) :
     if os.path.isfile(file_name): 
       os.remove(file_name)
         
-        
+####################################################################################################          
         
 def write_file(file_name, text, mode='w', is_new = False):
   file_folder = get_file_folder(file_name)
@@ -195,8 +200,16 @@ def write_file(file_name, text, mode='w', is_new = False):
   with codecs.open(file_name, mode, 'utf8') as fh:
     fh.write(text)
 
+####################################################################################################  
+
+
 def write_log(file_name, text, is_new = False):
   write_file(file_name=file_name, text=text + "\n", mode='a', is_new=is_new)
+
+
+####################################################################################################  
+
+
     
 def read_file(file_name, return_type='str'):
   if return_type == 'str' :
@@ -204,6 +217,10 @@ def read_file(file_name, return_type='str'):
     
   if return_type == 'list' :
     return codecs.open(file_name, 'r', 'utf8' ).readlines() 
+
+
+####################################################################################################
+
     
 def get_md5(file_name) :  
   hasher = hashlib.md5()
@@ -212,8 +229,17 @@ def get_md5(file_name) :
     hasher.update(buf)
   return (hasher.hexdigest())
 
+####################################################################################################
+
+
+
 def get_md5_txt(text) :  
   return hashlib.md5(text.encode('utf-8')).hexdigest()
+
+
+####################################################################################################
+
+
   
 def is_file (file) :
   return os.path.isfile(file) 
@@ -635,13 +661,18 @@ if __name__ == "__main__":
   """
   
   
-  
+  """
   split_file(input_file='R:/Temp2/disk.bin',output_folder='R:/Temp2', volume_size=1234)
   join_file(input_file='R:/Temp2/disk.bin', output_folder ='R:/Temp1')
   
   print (get_md5('R:/Temp2/disk.bin'))
   print (get_md5('R:/Temp1/disk.bin'))
   
+  """
+  
+  clean_folder('R:/TempVM/stage')
+  #rm_folder(folder_name='R:/TempVM/stage')
+  
   """
   rm_file(file_name = 'r:/temp1/1.txt') 
   rm_file(file_name = ['r:/temp1/1.txt', 'r:/temp1/3.txt'] ) 
